@@ -111,7 +111,7 @@ KJob *DWDIon::requestAPIJob(const QUrl &url, QByteArray &result)
 
     qCDebug(WEATHER::ION::DWD) << "Requesting URL:" << url;
 
-    connect(getJob, &KIO::TransferJob::data, this, [this, &result](KIO::Job *job, const QByteArray &data) {
+    connect(getJob, &KIO::TransferJob::data, this, [&result](KIO::Job *job, const QByteArray &data) {
         Q_UNUSED(job);
         if (data.isEmpty()) {
             return;
@@ -156,12 +156,12 @@ void DWDIon::findPlaces(std::shared_ptr<QPromise<std::shared_ptr<Locations>>> pr
 
     // Checks if the stations have already been loaded, always contains the currently active one
     if (!m_place.isEmpty()) {
-        qCDebug(WEATHER::ION::DWD) << "place list is not empy. Search in it";
+        qCDebug(WEATHER::ION::DWD) << "place list is not empty. Search in it";
         searchInStationList(m_searchString);
         m_locationPromise->finish();
         clearLocationData();
     } else {
-        qCDebug(WEATHER::ION::DWD) << "place list is not empy. Update it first";
+        qCDebug(WEATHER::ION::DWD) << "place list is not empty. Update it first";
         const auto getJob = requestAPIJob(QUrl(CATALOGUE_URL), m_locationsData);
         connect(getJob, &KJob::result, this, &DWDIon::places_slotJobFinished);
     }
@@ -198,9 +198,9 @@ void DWDIon::fetchForecast(std::shared_ptr<QPromise<std::shared_ptr<Forecast>>>
     // place_name|id - Triggers receiving weather of place
     const QList<QString> info = placeInfo.split('|'_L1);
 
-    if (info.size() == 4 && info[1] == "weather" && !m_isLegacy) {
+    if (info.size() == 4 && info[1] == "weather"_L1 && !m_isLegacy) {
         m_isLegacy = true;
-        fetchForecast(m_forecastPromise, info[2] + '|' + info[3]);
+        fetchForecast(m_forecastPromise, info[2] + '|'_L1 + info[3]);
         return;
     }
 
